summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs
diff options
context:
space:
mode:
authordoccvs <doccvs@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-08-15 16:43:33 +0000
committerdoccvs <doccvs@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-08-15 16:43:33 +0000
commitefa853402d6b1b6aa7cfe0ad20ea434bb77f5f0d (patch)
tree73a29256f24635ea95fd19748b5b7d09f50484b2 /TAO/orbsvcs
parentebca623c0342743eaf9495a7abcebfa3e29d4ef5 (diff)
downloadATCD-efa853402d6b1b6aa7cfe0ad20ea434bb77f5f0d.tar.gz
ChangeLogTag: Mon Tue 15 09:42:13 2000 Priyanka Gontla <pgontla@ece.uci.edu>
Diffstat (limited to 'TAO/orbsvcs')
-rw-r--r--TAO/orbsvcs/CosEvent_Service/CosEvent_Service_Native.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/TAO/orbsvcs/CosEvent_Service/CosEvent_Service_Native.cpp b/TAO/orbsvcs/CosEvent_Service/CosEvent_Service_Native.cpp
index 440a50a397a..a4886b76c26 100644
--- a/TAO/orbsvcs/CosEvent_Service/CosEvent_Service_Native.cpp
+++ b/TAO/orbsvcs/CosEvent_Service/CosEvent_Service_Native.cpp
@@ -31,7 +31,7 @@ class EventChannel : public TAO_CEC_EventChannel
// an application controled event loop.
// We don't use ORB::shutdown() because that leaves the ORB is a
// state where it is hard to cleanup the system.
- //
+ //
public:
EventChannel (const TAO_CEC_EventChannel_Attributes &attr,
int *terminate_flag);
@@ -56,24 +56,24 @@ main (int argc, char* argv[])
int result;
// Intialize the ORB
- CORBA::ORB_var orb =
+ CORBA::ORB_var orb =
CORBA::ORB_init (argc, argv, 0, ACE_TRY_ENV);
ACE_TRY_CHECK;
- // Call TAO_Event_Loader::init (argc, argv) from here.
- TAO_Event_Loader event_service;
+ // Call TAO_CEC_Event_Loader::init (argc, argv) from here.
+ TAO_CEC_Event_Loader event_service;
// To intialise the service
result = event_service.init (argc, argv);
-
+
if (result == -1)
return 1;
-
+
orb->run();
-
+
// Destroy the ORB
orb->destroy();
-
+
}
ACE_CATCHANY
{